#!/usr/bin/python3

#
# Copyright (C) 2022 Jonathan Certes
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program. If not, see <http://www.gnu.org/licenses/>.
#

# IMPORTANT! sikuliX API must be running py4j server on port 25333
# we must run: java -jar "sikulixapi-*.jar" -p
import sikulix4python

# where the script is:
theScript  = sikulix4python.os.path.realpath(__file__)
theDirname = sikulix4python.os.path.dirname(theScript)

# location of the images for pattern recognition:
img_file    = sikulix4python.os.path.join(theDirname, "file.png")
img_print   = sikulix4python.os.path.join(theDirname, "print.png")
img_save    = sikulix4python.os.path.join(theDirname, "save.png")
img_name    = sikulix4python.os.path.join(theDirname, "name.png")
img_save_as = sikulix4python.os.path.join(theDirname, "save_as.png")
img_replace = sikulix4python.os.path.join(theDirname, "replace.png")

#===============================================================================

def sikuli_waitExists(
  theScreen,    #!< sikulix4python screen instance
  theImagePath  #!< path to the image we wait to be visible
):
  while ( True ):
    theRegion = theScreen.exists(theImagePath)
    if ( theRegion is not None ):
      break
    else:
      print("wait for " + theImagePath)
  return theRegion

#===============================================================================

sikulix4python.time.sleep(1)

# create parent directories if they do not exist:
theDestFile = "/tmp/test.pdf"
theDirname = sikulix4python.os.path.dirname(theDestFile)
sikulix4python.os.makedirs(theDirname, exist_ok=True)

# NOW, NOTHING HAPPENS IF FIREFOX IS NOT RUNNING AND VISIBLE.

# click File -> Print:
theRegion = sikuli_waitExists(sikulix4python.SCREEN.instance, img_file)
theRegion.click()
#
theRegion = sikuli_waitExists(sikulix4python.SCREEN.instance, img_print)
theRegion.click()

# click save button:
theRegion = sikuli_waitExists(sikulix4python.SCREEN.instance, img_save)
theRegion.click()

# wait for the "Name" pop-up to appear:
theRegion = sikuli_waitExists(sikulix4python.SCREEN.instance, img_name)
# add pixels to X of the region and click:
theRegion.setX(theRegion.getX() + 300)
theRegion.click()

# save as:
theRegion.type(sikulix4python.SXPKG.script.Key.BACKSPACE * 30)
theRegion.paste(theDestFile)
theRegion.type(sikulix4python.SXPKG.script.Key.ENTER)
#
theRegion = sikuli_waitExists(sikulix4python.SCREEN.instance, img_save_as)
theRegion.click()
#
theRegion = sikulix4python.SCREEN.instance.exists(img_replace)
if ( theRegion is not None ):
  theRegion.click()

# wait for everything to disappear:
sikulix4python.SCREEN.instance.waitVanish(img_replace)
sikulix4python.SCREEN.instance.waitVanish(img_save_as)
sikulix4python.SCREEN.instance.waitVanish(img_save)

print("OK!")
